@@ -8,7 +8,7 @@ use Carp;
 
 use subs qw();
 
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 
 =encoding utf8
 
@@ -99,7 +99,6 @@ sub version {
 
 	croak( "$class doesn't know about method [$method]" ) unless
 		eval { $class->can( $method ) };
-
 	my @list = $class->$method;
 	unless( wantarray ) {
 		return join ".", @list[0,1], (defined($list[2]) ? $list[2] : ());
@@ -198,6 +197,8 @@ sub major_version_exists {
 
 sub minor_to_name {
 	my( $class, $minor, $major ) = @_;
+	carp "No MAJOR argument to minor_to_name is deprecated. It will assume " . $class->default_major_version
+		unless defined $major;
 	$major //= $class->default_major_version;
 	croak "Unknown Mac version <$major>" unless $class->major_version_exists( $major );
 	$major == 10 ? $names{$major}[ $minor ] : $names{$major}[ 0 ]
@@ -379,7 +380,7 @@ sub sw_vers {
 
 	( $list[_MAJOR], $list[_MINOR], $list[_POINT] ) = split /\./, $product;
 	$list[_BUILD] = $build;
-	$list[_NAME] = $class->minor_to_name( $list[_MINOR] );
+	$list[_NAME] = $class->minor_to_name( $list[_MINOR], $list[_MAJOR] );
 
 	@list;
 	}
@@ -421,7 +422,7 @@ sub system_profiler {
 
 		$list[_BUILD]  = $build;
 		$list[_KERNEL] = $kernel;
-		$list[_NAME]   = $class->minor_to_name( $list[_MINOR] );
+		$list[_NAME]   = $class->minor_to_name( $list[_MINOR], $list[_MAJOR] );
 		}
 
 	@list;
